@@ -157,9 +157,13 @@ class VariableClReqBaseData(Variable):
         certbase = self.Get('cl_core_database')
 
         for line in readLinesFile(certbase):
-            if line.split()[0] == str(req_id):
-                return line.strip().split()
-        return [''] * 7
+            data = line.strip().split()
+            if len(data) < 6:
+                continue
+            data += [""] * (8-len(data))
+            if data[0] == str(req_id):
+                return data
+        return [''] * 8
 
 
 class VariableClReqData(Variable):
